Learn R Programming

RclusTool (version 0.91.5)

ElbowPlot: Elbow Plot.

Description

Display the Elbow Plot after a clustering step.

Usage

ElbowPlot(nb, method.space.name, RclusTool.env, hscale = 1.2, charsize = 11)

Value

None

Arguments

nb

tk-notebook in which the Elbow plot will be made.

method.space.name

complete name of space.

RclusTool.env

: environment in which data and intermediate results are stored.

hscale

numeric value corresponding to the horizontal scale of graphic

charsize

character size

Details

ElbowPlot displays the Elbow plot after a clustering step.